==> jc-1.4.0.tar.gz: soot/jimple/parser/node/ADivBinop.h <==
// public final class soot.jimple.parser.node.ADivBinop

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class ddee52e82af61e9a soot_jimple_parser_node_ADivBinop
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class b86441297795c006 soot_jimple_parser_node_PBinop

// header file dependencies
// @dep_header soot_jimple_parser_node_PBinop

#include "soot/jimple/parser/node/PBinop.h"

#ifndef _JC_soot_jimple_parser_node_ADivBinop_H_
#define _JC_soot_jimple_parser_node_ADivBinop_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TDiv$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_ADivBinop$sub_refs	_jc_soot_jimple_parser_node_ADivBinop$sub_refs;
typedef struct _jc_soot_jimple_parser_node_ADivBinop$sub_nonrefs	_jc_soot_jimple_parser_node_ADivBinop$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_ADivBinop$refs	_jc_soot_jimple_parser_node_ADivBinop$refs;
typedef struct _jc_soot_jimple_parser_node_ADivBinop$nonrefs	_jc_soot_jimple_parser_node_ADivBinop$nonrefs;
typedef struct _jc_soot_jimple_parser_node_ADivBinop$object	_jc_soot_jimple_parser_node_ADivBinop$object;

typedef const struct _jc_soot_jimple_parser_node_ADivBinop$vmethods	_jc_soot_jimple_parser_node_ADivBinop$vmethods;
typedef const struct _jc_soot_jimple_parser_node_ADivBinop$vtable	_jc_soot_jimple_parser_node_ADivBinop$vtable;
typedef const struct _jc_soot_jimple_parser_node_ADivBinop$vtype	_jc_soot_jimple_parser_node_ADivBinop$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_ADivBinop$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_ADivBinop$object *);
extern void _jc_soot_jimple_parser_node_ADivBinop$method$_init$e099b007afbb393b(_jc_env *, struct _jc_soot_jimple_parser_node_ADivBinop$object *, struct _jc_soot_jimple_parser_node_TDiv$object *);

// Virtual methods
extern void _jc_soot_jimple_parser_node_ADivBinop$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_ADivBinop$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_ADivBinop$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_ADivBinop$object *);
extern struct _jc_soot_jimple_parser_node_TDiv$object *_jc_soot_jimple_parser_node_ADivBinop$method$getDiv$143711f97a6ec204(_jc_env *, struct _jc_soot_jimple_parser_node_ADivBinop$object *);
extern void _jc_soot_jimple_parser_node_ADivBinop$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_ADivBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_ADivBinop$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_ADivBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_ADivBinop$method$setDiv$b131660414688061(_jc_env *, struct _jc_soot_jimple_parser_node_ADivBinop$object *, struct _jc_soot_jimple_parser_node_TDiv$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_ADivBinop$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_ADivBinop$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_ADivBinop$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_ADivBinop$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_ADivBinop$method_info$getDiv$143711f97a6ec204;
extern _jc_method _jc_soot_jimple_parser_node_ADivBinop$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_ADivBinop$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_ADivBinop$method_info$setDiv$b131660414688061;
extern _jc_method _jc_soot_jimple_parser_node_ADivBinop$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_ADivBinop$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_ADivBinop$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_ADivBinop$object *);
	struct _jc_soot_jimple_parser_node_TDiv$object	*(*getDiv$143711f97a6ec204)(_jc_env *, struct _jc_soot_jimple_parser_node_ADivBinop$object *);
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_ADivBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_ADivBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*setDiv$b131660414688061)(_jc_env *, struct _jc_soot_jimple_parser_node_ADivBinop$object *, struct _jc_soot_jimple_parser_node_TDiv$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_ADivBinop$object *);
};

// Vtable
struct _jc_soot_jimple_parser_node_ADivBinop$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PBinop$vmethods	soot_jimple_parser_node_PBinop;
	_jc_soot_jimple_parser_node_ADivBinop$vmethods	soot_jimple_parser_node_ADivBinop;
};

// Vtype
struct _jc_soot_jimple_parser_node_ADivBinop$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_ADivBinop$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ADivBinop$sub_refs {
	struct _jc_soot_jimple_parser_node_TDiv$object	*__5fdiv__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_ADivBinop$refs {
    _jc_soot_jimple_parser_node_ADivBinop$sub_refs	soot_jimple_parser_node_ADivBinop;
    _jc_soot_jimple_parser_node_PBinop$sub_refs	soot_jimple_parser_node_PBinop;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ADivBinop$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_ADivBinop$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PBinop$sub_nonrefs	soot_jimple_parser_node_PBinop;
    _jc_soot_jimple_parser_node_ADivBinop$sub_nonrefs	soot_jimple_parser_node_ADivBinop;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_ADivBinop$object {
	_jc_soot_jimple_parser_node_ADivBinop$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_ADivBinop$vtype	*vtype;
	_jc_soot_jimple_parser_node_ADivBinop$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_ADivBinop$vtype _jc_soot_jimple_parser_node_ADivBinop$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_ADivBinop, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_ADivBinop$class_object;

#endif	/* _JC_soot_jimple_parser_node_ADivBinop_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/node/ADivBinop.h <==
// public final class soot.jimple.parser.node.ADivBinop

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class ddee52e82af61e9a soot_jimple_parser_node_ADivBinop
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class b86441297795c006 soot_jimple_parser_node_PBinop

// header file dependencies
// @dep_header soot_jimple_parser_node_PBinop

#include "soot/jimple/parser/node/PBinop.h"

#ifndef _JC_soot_jimple_parser_node_ADivBinop_H_
#define _JC_soot_jimple_parser_node_ADivBinop_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TDiv$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_ADivBinop$sub_refs	_jc_soot_jimple_parser_node_ADivBinop$sub_refs;
typedef struct _jc_soot_jimple_parser_node_ADivBinop$sub_nonrefs	_jc_soot_jimple_parser_node_ADivBinop$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_ADivBinop$refs	_jc_soot_jimple_parser_node_ADivBinop$refs;
typedef struct _jc_soot_jimple_parser_node_ADivBinop$nonrefs	_jc_soot_jimple_parser_node_ADivBinop$nonrefs;
typedef struct _jc_soot_jimple_parser_node_ADivBinop$object	_jc_soot_jimple_parser_node_ADivBinop$object;

typedef const struct _jc_soot_jimple_parser_node_ADivBinop$vmethods	_jc_soot_jimple_parser_node_ADivBinop$vmethods;
typedef const struct _jc_soot_jimple_parser_node_ADivBinop$vtable	_jc_soot_jimple_parser_node_ADivBinop$vtable;
typedef const struct _jc_soot_jimple_parser_node_ADivBinop$vtype	_jc_soot_jimple_parser_node_ADivBinop$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_ADivBinop$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_ADivBinop$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ADivBinop$method$_init$e099b007afbb393b(_jc_env *, struct _jc_soot_jimple_parser_node_ADivBinop$object *, struct _jc_soot_jimple_parser_node_TDiv$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_parser_node_ADivBinop$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_ADivBinop$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_ADivBinop$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_ADivBinop$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_parser_node_TDiv$object *_jc_soot_jimple_parser_node_ADivBinop$method$getDiv$143711f97a6ec204(_jc_env *, struct _jc_soot_jimple_parser_node_ADivBinop$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ADivBinop$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_ADivBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ADivBinop$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_ADivBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ADivBinop$method$setDiv$b131660414688061(_jc_env *, struct _jc_soot_jimple_parser_node_ADivBinop$object *, struct _jc_soot_jimple_parser_node_TDiv$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_ADivBinop$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_ADivBinop$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_ADivBinop$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_ADivBinop$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_ADivBinop$method_info$getDiv$143711f97a6ec204;
extern _jc_method _jc_soot_jimple_parser_node_ADivBinop$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_ADivBinop$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_ADivBinop$method_info$setDiv$b131660414688061;
extern _jc_method _jc_soot_jimple_parser_node_ADivBinop$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_ADivBinop$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_ADivBinop$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_ADivBinop$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_parser_node_TDiv$object	*(*getDiv$143711f97a6ec204)(_jc_env *, struct _jc_soot_jimple_parser_node_ADivBinop$object *) _JC_JCNI_ATTR;
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_ADivBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_ADivBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*setDiv$b131660414688061)(_jc_env *, struct _jc_soot_jimple_parser_node_ADivBinop$object *, struct _jc_soot_jimple_parser_node_TDiv$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_ADivBinop$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_node_ADivBinop$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PBinop$vmethods	soot_jimple_parser_node_PBinop;
	_jc_soot_jimple_parser_node_ADivBinop$vmethods	soot_jimple_parser_node_ADivBinop;
};

// Vtype
struct _jc_soot_jimple_parser_node_ADivBinop$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_ADivBinop$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ADivBinop$sub_refs {
	struct _jc_soot_jimple_parser_node_TDiv$object	*__5fdiv__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_ADivBinop$refs {
    _jc_soot_jimple_parser_node_ADivBinop$sub_refs	soot_jimple_parser_node_ADivBinop;
    _jc_soot_jimple_parser_node_PBinop$sub_refs	soot_jimple_parser_node_PBinop;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ADivBinop$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_ADivBinop$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PBinop$sub_nonrefs	soot_jimple_parser_node_PBinop;
    _jc_soot_jimple_parser_node_ADivBinop$sub_nonrefs	soot_jimple_parser_node_ADivBinop;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_ADivBinop$object {
	_jc_soot_jimple_parser_node_ADivBinop$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_ADivBinop$vtype	*vtype;
	_jc_soot_jimple_parser_node_ADivBinop$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_ADivBinop$vtype _jc_soot_jimple_parser_node_ADivBinop$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_ADivBinop, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_ADivBinop$class_object;

#endif	/* _JC_soot_jimple_parser_node_ADivBinop_H_ */
